@@ -2,9 +2,25 @@
 
 """
 DOM wrapper around libxml2, specifically the libxml2mod Python extension module.
+
+Copyright (C) 2003, 2004, 2005 Paul Boddie <paul@boddie.org.uk>
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
-__version__ = "0.3.2"
+__version__ = "0.3.3"
 
 from libxml2dom.macrolib import *
 from libxml2dom.macrolib import \
@@ -13,7 +29,6 @@ from libxml2dom.macrolib import \
     parseFile as Node_parseFile, \
     toString as Node_toString, toStream as Node_toStream, \
     toFile as Node_toFile
-import weakref
 
 # Attribute and node list wrappers.
 
@@ -391,10 +406,9 @@ class Document(Node):
 
     def __init__(self, node):
         self._node = node
-        self.weakref_ownerDocument = weakref.ref(self)
 
     def _ownerDocument(self):
-        return self.weakref_ownerDocument()
+        return self
 
     def _parentNode(self):
         return None
